@@ -51,7 +51,7 @@ def snowflake_engine_factory(
             "USER": "SNOWFLAKE_LOAD_USER",
             "PASSWORD": "SNOWFLAKE_LOAD_PASSWORD",
             "ACCOUNT": "SNOWFLAKE_ACCOUNT",
-            "DATABASE": "SNOWFLAKE_TRANSFORM_DATABASE",
+            "DATABASE": "SNOWFLAKE_PROD_DATABASE",
             "WAREHOUSE": "SNOWFLAKE_LOAD_WAREHOUSE",
             "ROLE": "LOADER",
         },
@@ -67,7 +67,7 @@ def snowflake_engine_factory(
             "USER": "SNOWFLAKE_USER",  ## this is the CI User
             "PASSWORD": "SNOWFLAKE_PASSWORD",
             "ACCOUNT": "SNOWFLAKE_ACCOUNT",
-            "DATABASE": "SNOWFLAKE_TRANSFORM_DATABASE",
+            "DATABASE": "SNOWFLAKE_PROD_DATABASE",
             "WAREHOUSE": "SNOWFLAKE_TRANSFORM_WAREHOUSE",
             "ROLE": "TRANSFORMER",
         },
@@ -151,7 +151,12 @@ def dataframe_uploader(
 
 
 def snowflake_stage_load_copy_remove(
-    file: str, stage: str, table_path: str, engine: Engine, type: str = "json"
+    file: str,
+    stage: str,
+    table_path: str,
+    engine: Engine,
+    type: str = "json",
+    on_error="skip_file",
 ) -> None:
     """
     Upload file to stage, copy to table, remove file from stage on Snowflake
@@ -162,7 +167,7 @@ def snowflake_stage_load_copy_remove(
     copy_query = f"""copy into {table_path} (jsontext)
                      from @{stage}
                      file_format=(type='{type}'),
-                     on_error='skip_file';"""
+                     on_error='{on_error}';"""
 
     remove_query = f"remove @{stage} pattern='.*.{type}.gz'"
 
@@ -212,7 +217,7 @@ def push_to_xcom_file(xcom_json: Dict[Any, Any]) -> None:
 
 def append_to_xcom_file(xcom_json: Dict[Any, Any]) -> None:
     """
-    Combines the parameter dictionary with any XComs that have already been written by the KubernetesPodOperator.  
+    Combines the parameter dictionary with any XComs that have already been written by the KubernetesPodOperator.
     This function is useful because the XComs can be written at any time during the Task run and not be written over.
     """
 
